/****************************************************************************************
 * Copyright (C) 2012 Lucien XU <sfietkonstantin@free.fr>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 3 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: container
    property int editIndex: -1
    property alias name: nameText.text
    property string icon: "/usr/share/themes/blanco/meegotouch/icons/icon-l-default-application.png"
    property string apk
    function reset() {
        editIndex = -1
        container.name = ""
        container.apk = ""
    }
    onApkChanged: apkButton.updateApk()

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }

        ToolButton {
            text: qsTr("Save")
            enabled: name.text != "" && container.apk != ""
            anchors.centerIn: parent
            onClicked: {
                if (editIndex != -1) {
                    LAUNCHER_MODEL.editLauncher(container.editIndex, container.name, container.icon,
                                                container.apk)
                } else {
                    LAUNCHER_MODEL.addLauncher(container.name, container.icon, container.apk)
                }

                LAUNCHER_MODEL.update()
                window.pageStack.pop()
            }
        }
    }

    Label {
        id: title
        anchors.left: parent.left; anchors.leftMargin: 16
        anchors.right: parent.right; anchors.rightMargin: 16
        anchors.top: parent.top; anchors.topMargin: 16
        text: qsTr("Add a launcher")
        font.pixelSize: 32
    }

    HorizontalSeparator {
        id: separator
        anchors.top: title.bottom; anchors.topMargin: 16
    }

    Flickable {
        clip: true
        anchors.top: separator.bottom; anchors.topMargin: 16
        anchors.bottom: parent.bottom
        anchors.left: parent.left; anchors.right: parent.right
        contentWidth: container.width
        contentHeight: nameText.height + icon.height + apk.height + 2 * 16

        TextField {
            id: nameText
            anchors.left: parent.left; anchors.leftMargin: 16
            anchors.right: parent.right; anchors.rightMargin: 16
            placeholderText: qsTr("Display name")
        }

        TextField {
            id: icon
            anchors.left: parent.left; anchors.leftMargin: 16
            anchors.right: parent.right; anchors.rightMargin: 16
            anchors.top: nameText.bottom; anchors.topMargin: 16
            placeholderText: qsTr("Icon (not available yet)")
            enabled: false
        }

        Button {
            id: apkButton
            function updateApk() {
                apkButton.text = APK_MODEL.apkName(container.apk)
            }

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: icon.bottom; anchors.topMargin: 16
            onClicked: {
                window.pageStack.push(selectApkPage)
                APK_MODEL.select(APK_MODEL.apkRow(container.apk))
            }

            Connections {
                target: APK_MODEL
                onUpdatingChanged: {
                    if (!APK_MODEL.updating) {
                        apkButton.updateApk()
                    }
                }
            }
        }
    }

    SelectApkPage {
        id: selectApkPage
        onApkSelected: {
            container.apk = APK_MODEL.currentApk
            apkButton.updateApk()
        }
    }
}
