/****************************************************************************************
 * Copyright (C) 2012 Lucien XU <sfietkonstantin@free.fr>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 3 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

import QtQuick 1.1

Item {
    id: container
    property bool deleteMode: false
    property alias name: text.text
    property alias icon: icon.source
    signal clicked()
    width: 110
    height: 110

    Image {
        id: deleteIcon
        width: 80
        height: 80
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        opacity: 0
        scale: 0.5
        source: "image://theme/icon-m-browser-stop"
    }

    Image {
        id: icon
        width: 80
        height: 80
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Text {
        id: text
        anchors.top: icon.bottom
        anchors.topMargin: 8
        width: parent.width
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 16
        wrapMode: Text.NoWrap
        elide: Text.ElideRight
        color: theme.inverted ? "white" : "black"
    }

    MouseArea {
        anchors.fill: parent
        onClicked: container.clicked()
    }

    states: [
        State {
            name: "deleteMode"; when: container.deleteMode
            PropertyChanges {
                target: deleteIcon
                opacity: 1
                scale: 1
            }

            PropertyChanges {
                target: icon
                opacity: 0
                scale: 0.5
            }

            PropertyChanges {
                target: text
                opacity: 0.8
            }
        }
    ]

    transitions: [
        Transition {
            NumberAnimation {
                target: deleteIcon
                properties: "opacity,scale"
                duration: 200
            }

            NumberAnimation {
                target: icon
                properties: "opacity,scale"
                duration: 200
            }

            NumberAnimation {
                target: text
                property: "opacity"
                duration: 200
            }
        }
    ]
}
