/****************************************************************************************
 * Copyright (C) 2012 Lucien XU <sfietkonstantin@free.fr>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 3 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: window
    initialPage: mainPage
    Component.onCompleted: {
        theme.inverted = true
    }

    Page {
        id: mainPage
        property bool deleteMode: false
        tools: ToolBarLayout {
            ToolIcon {
                iconId: "toolbar-add"
                onClicked: {
                    addLauncherPage.reset()
                    window.pageStack.push(addLauncherPage)
                }
            }

            ToolIcon {
                iconId: "toolbar-refresh"
                onClicked: LAUNCHER_MODEL.update()
            }

            ToolIcon {
                iconId: !mainPage.deleteMode ? "toolbar-delete" : "toolbar-done"
                onClicked: mainPage.deleteMode = !mainPage.deleteMode
            }
        }

        GridView {
            id: grid
            model: LAUNCHER_MODEL
            width: Math.floor(parent.width / (cellWidth)) * cellWidth
            height: parent.height
            clip: true
            anchors.centerIn: parent
            cellWidth: 110 + 2 * 4
            cellHeight: 110 + 2 * 20
            delegate: Item {
                width: grid.cellWidth
                height: grid.cellHeight

                Icon {
                    anchors.centerIn: parent
                    deleteMode: mainPage.deleteMode
                    name: model.name
                    icon: model.icon
                    onClicked: {
                        if (deleteMode) {
                            LAUNCHER_MODEL.removeLauncher(model.file)
                        } else {
                            addLauncherPage.editIndex = model.index
                            addLauncherPage.name = model.name
                            addLauncherPage.icon = model.icon
                            addLauncherPage.apk = model.apk
                            window.pageStack.push(addLauncherPage)
                        }
                    }
                }
            }
        }

        BusyIndicator {
            anchors.centerIn: parent
            visible: LAUNCHER_MODEL.updating && mainPage.visible
            running: LAUNCHER_MODEL.updating
            platformStyle: BusyIndicatorStyle {size: "large"}
        }
    }

    AddLauncherPage {
        id: addLauncherPage
    }
}
